function plot_kckg(p)
%PLOT_KCKG Plots the gravity and capillary wavenumber of the Kelvin wake.
%   PLOT_KCKG plots the range of excitable wavenumbers [kc,kg] of the
%   Kelvin Wake, as a function of the stream velocity, for deep water.
%
%   PLOT_KCKG(P) specifies the parameter structure P (see WAVE_PARAMETER
%   for the default values)
% 

error(nargchk(0,1,nargin));

if nargin==0
    p=[];
end

p = wave_parameter(p);   % fills the default values in p

v = linspace(0,1,1000);  % velocity, m/s
[kc, kg] = kckg(v,p);  % wavenumbers selected by the velocity
loglog(v,kc,'r-',v,kg,'b-');
xlabel('V, m/s');
ylabel('k_c,  k_g,  m^{-1}')
xlim([.1 1])
