function plot_lambda(h0)
%PLOT_LAMBDA  Plot the wavelength versus frequency
%   PLOT_LAMBDA plots the wavelength as a function of frequency in
%   deepwater, for various values of the surface tension gamma. 
%   PLOT_LAMBDA(H0) specifies the water depth H0 (in m).

if nargin==0
    h0=inf;
end

p  = wave_parameter('h0',h0);

gam = [70 60 50]*1e-3;   % values of surface tension (N/m)

hold off
for i=1:length(gam)
    p = wave_parameter(p,'gamma',gam(i));
    lambda=linspace(4,30,1e4)/1000;
    k=2*pi./lambda;
    freq=omega(k,p)/(2*pi);
    plot(freq,1000*lambda);
    hold on
    xlabel('f (Hz)')
    ylabel('\lambda (mm)')
    %title(['h_0 = ' num2str(h0) ' m']);
end
axis([0 50 0 25])
grid minor
title('\gamma = 50, 60, 70 mN m');